@@ -2,13 +2,13 @@
 
 __author__ = """Daniel Böckenhoff"""
 __email__ = "dboe@ipp.mpg.de"
-__version__ = "0.6.5"
+__version__ = "0.7.0"
 
-from . import plotting
 from . import log  # NOQA
 from . import path  # NOQA
 from . import process  # NOQA
 from . import pattern  # NOQA
 from . import polymorphism  # NOQA
+from . import plotting
 
-plotting.use("matplotlib")
+plotting.use("matplotlib")  # TODO: remove
