@@ -6,6 +6,29 @@ import logging
 import time
 
 
+def pipe(pipe_obj, level=logging.DEBUG, prefix=""):
+    """
+    Logging a subprocess pipe
+
+    Examples:
+        >>> import logging
+        >>> import subprocess
+        >>> import rna
+        >>> log = logging.getLogger(__name__)
+        >>> process = subprocess.Popen(
+        ...     ["echo", "Hello World"],
+        ...     stdout=subprocess.PIPE,
+        ...     stderr=subprocess.STDOUT)
+
+        >>> with process.stdout:
+        ...     rna.log.pipe(process.stdout, level=logging.ERROR)
+        >>> exitcode = process.wait() # 0 means success
+
+    """
+    for line in iter(pipe_obj.readline, b""):  # b'\n'-separated lines
+        logging.log(level, "%s: %r", prefix, line)
+
+
 def progressbar(iterable, log=None):
     """
     Args:
@@ -63,6 +86,12 @@ def timeit(process_name="No Description", log=None, precision=1) -> None:
         process_name (str): message to customize the log message
         log (logger)
         precision (int): show until 10^-<precision> digits
+
+    Examples:
+        >>> import rna
+        >>> with rna.log.timeit("Logger Name"):
+        ...     # Some very long calculation
+        ...     pass
     """
     if log is None:
         log = logging
@@ -79,9 +108,3 @@ def timeit(process_name="No Description", log=None, precision=1) -> None:
             value=time.time() - start_time, precision=precision
         ),
     )
-
-
-if __name__ == "__main__":
-    import doctest
-
-    doctest.testmod()
